
use "data1.dta", clear
generate region=0 if state>=0 & state<=9
replace region=1 if state>=12 & state<=16
label define lbregion 0 "West" 1 "Ost"
label values region lbregion

putdocx clear

putdocx begin
putdocx textblock begin, style(Title)
Vergleich Lebenszufriedenheit West-Ost
putdocx textblock end

putdocx textblock begin 
Wir sehen hier die deskriptive Darstellung der Variablen, die wir für unser Modell verwenden:
putdocx textblock end

collect style putdocx, layout(autofitcontents)
quietly: dtable lsat i.sex i.edu hhinc hsat, by(region) title("Tabelle 1") nformat(%6.1f)
putdocx collect
putdocx textblock begin 
Das OLS-Regressionsmodell zeigt uns, dass Frauen ein wenig lebenszufriedener sind als Männer, Bildung keinen signifikanten Einfluss auf die Lebenszufriedenheit hat, die Zufriedenheit mit der eigenen Gesundheit sich jedoch sehr stark positiv auf die Lebenszufriedenheit auswirkt.
putdocx textblock end

quietly: regress lsat i.sex
quietly: estimates store model1
quietly: regress lsat i.sex i.edu 
quietly: estimates store model2
quietly: regress lsat i.sex i.edu hsat
quietly: estimates store model3
etable, ///
	estimates(model1 model2 model3) ///
	cstat(_r_b) ///
	showstars showstarsnote ///
	mstat(N) mstat(r2) ///
	column(index)
putdocx collect

graph twoway (scatter lsat hsat, jitter(10)) (lfit lsat hsat)
graph export "graph1.svg", replace
putdocx paragraph, halign(center)
putdocx text ("Abbildung 1: Lebens- und Gesundheitszufriedenheit"), bookmark("bmark1")
putdocx image "graph1.svg", linebreak
putdocx paragraph, halign(left)

putdocx textblock begin 
In <<dd_docx_display bookmarklink("bmark1"): "Abbildung 1">> sehen wir den bivariaten Zusammenhang von Lebens- und Gesundheitszufriedenheit.
putdocx textblock end

putdocx save "ergebnisse1.docx", replace
putdocx clear



