{smcl}
{*:author: C. Brzinsky-Fay, time: started 07/2024}
{marker inhalt}
{hline}


{center:{ul on}{yellow:Neue Funktionen in Stata 18}{ul off}}

{center:{hi:Christian Brzinsky-Fay, DPC Software}}
{center:{it:Kontakt:christian.brzinsky-fay@dpc-software.de}}}


{pstd}
{title:{yellow:Übersicht}}

{phang2} {help webcast01##colorvar:1) colorvar()-Option für farbliche Darstellung von Drittvariablen}{break} {p_end}

{phang2} {help webcast01##documents:2) Dynamische Dokumentenerstellung mit Stata-Ergebnissen}{break} {p_end}

{phang2} {help webcast01##mediation:3) Causal Mediation Analysis}{break} {p_end}


{marker colorvar}
{hline}

{center:{ul on}{yellow:1) colorvar()-Option für farbliche Darstellung von Drittvariablen}{ul off}}

{pstd}
Hier demonstriere ich Ihnen, wie Sie in einem Streudiagramm (und auch in anderen {cmd:twoway}-Diagrammen) die Marker farblich nach den Werten einer dritten Variable unterscheiden können.

{pstd}
Diese Feature wurde in Stata 18 neu eingeführt und in StataNow auf weitere Grafiktypen ausgeweitet.

{hline}

{title:Ein einfaches Streudiagramm}

{phang2} {stata sysuse "auto.dta", clear} {p_end}

{pstd}
Wir laden zunächst den berühmten Stata-Beispieldatensatz {cmd:auto.dta}, der ein paar Informationen zu verschiedenen Autotypen enthält. 
Das Streudiagramm zeigt die Kovariation der zwei Variablen Spritverbrauch ({cmd:mpg}) und Preis ({cmd:price}). 

{pstd}
Die Merkmale sind hier in amerikanischen Einheiten gemessen, also der Spritverbrauch in Meilen pro Gallone Benzin bzw. der Preis in Dollar.

{phang2} {stata graph twoway scatter mpg price} {p_end}

{pstd}
Man kann einen negativen Zusammenhang zwischen beiden Variablen erkennen: je höher der Preis, desto niedriger die Reichweite, d.h. je höher der Preis, desto höher der Spritverbrauch.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{title:Eine dritte Variable}

{pstd}
Der Zusammenhang zwischen Preis und Verbrauch wird sicherlich noch von anderen Eigenschaften eines Autotyps beeinflusst. Es wäre beispielsweise denkbar, dass auch das Gewicht eines Autos Einfluss auf den Verbrauch hat. 

{pstd}
Die entsprechende Variable {cmd:weight} schauen wir uns zunächst mit {cmd:summarize} an.

{phang2} {stata summarize weight} {p_end}

{pstd}
Auch hier hat die Variable wieder eine amerikanische Einheit, und zwar amerikanische Pfund (1 Pfund = ca. 0.45kg).

{pstd}
Wir stellen dann den Zusammenhang zwischen den beiden Ausgangsvariablen ({cmd:mpg} und {cmd:price}) unter Einbeziehung einer dritten Variable ({cmd:weight}) grafisch in dem gleichen Streudiagramm mit differenzierten Farben dar.

{phang2} {stata graph twoway scatter mpg price, colorvar(weight)} {p_end}

{pstd}
Auf der rechten Seite erhalten wir jetzt eine Skala, die automatisch die (kontinuierliche) Drittvariable klassiert, also in Intervalle einteilt und diesen kontrastreiche Farben zuordnet. 

{pstd}
Die leichtesten Autotypen (bis 2000 Pfund, ca. 907kg) sind in Dunkelblau dargestellt, gefolgt von Türkis und Grün, während die schwersten Autotypen (ab 4000 Pfund, ca. 1814kg) die Farbe Gelb erhalten.

{pstd}
Wir können hier feststellen, dass die leichteren Autotypen (blau) die größte Reichweite (Meilen pro Gallone Benzin), d.h. den geringsten Verbrauch haben, und dabei im Preis relativ wenig variieren. 
Die schweren Autotypen (gelb) haben alle eine geringe Reichweite, d.h. einen hohen Verbrauch, variieren dafür aber beträchtlich im Preis.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{title:Wenn die Drittvariable diskret ist}

{pstd}
Wenn eine Variable nur ganzzahlige (oder gerundete) Werte annimmt, wird sie als diskrete Variable bezeichnet.
Beispielsweise könnten wir uns die Gewichtsvariable auch mit auf Tausender gerundeten Werten vorstellen, was wir mit einer Umrechnung erreichen.

{phang2} {stata generate weight2=int(weight/1000)*1000} {p_end}

{pstd}
Für die neue diskrete Variable {cmd:weight2} können nun keine automatischen Intervalle gebildet werden,
da sie ja nur die Werte 1000, 2000, 3000 oder 4000 annehmen kann.

{phang2} {stata tabulate weight2} {p_end}

{phang2} {stata graph twoway scatter mpg price, colorvar(weight2) colordiscrete} {p_end}

{pstd}
Durch die Angabe der Option {cmd:colordiscrete} teilen wir Stata mit, dass hier keine Intervalle für die Drittvariable gebildet werden sollen.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{title:Wenn die Drittvariable kategorial ist}

{pstd}
Ein diskrete Variable hat zwar nur eine begrenzte Zahl an Ausprägungen, ist aber trotz allem metrisch skaliert.
Die Ausprägungen (1000, 2000, 3000 bzw. 4000) repräsentieren daher Zahlen mit vergleichbaren Abständen.
Liegt eine Drittvariable vor, die nominal (bzw. kategorial) skaliert ist, ist der Zahlenwert nicht von Bedeutung, sondern repräsentiert nur unterscheidbare Kategorien.
In der Legende der Drittvariablen sollten demnach die Kategorien benannt werden. 

{pstd}
Ein Beispiel wäre hier die Variable {cmd:foreign}, die kennzeichnet, ob ein Autotyp aus den USA (Zahlenwert 0, domestic) oder aus dem Ausland (Zahlenwert 1, foreign) kommt.

{phang2} {stata tabulate foreign} {p_end}
{phang2} {stata tabulate foreign, nolabel} {p_end}

{pstd}
Das Streudiagramm mit allen drei Variablen wird wie im vorangegangenen Beispiel erzeugt, benötigt aber zwei zusätzliche Optionen, um die Legende entsprechend zu formatieren.

{phang2} {stata graph twoway scatter mpg price, colorvar(foreign) colordiscrete coloruseplegend zlabel(, valuelabel)}

{pstd}
Die Option {cmd:coloruseplegend} definiert die kategoriale Legende, während die Option {cmd:zlabel(, valuelabel)} anstelle der internen Zahlenwerte die zugeordneten Wertelabel der Variable {cmd:foreign} für die Darstellung verwendet.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{title:Die Verwendung von Farben für Drittvariablen}

{phang2} {stata graph twoway scatter mpg price, colorvar(weight2) colordiscrete} {p_end}

{pstd}
Die Farben werden bei Anwendung der {cmd:colorvar}-Option automatisch berechnet, können aber auch von Hand gesteuert werden.
Hierfür können wir die {cmd:colorstart}- und die {cmd:colorend}-Optionen verwenden, mit denen die erste und die letzte Farbe bestimmt werden.
Die Farben dazwischen werden in jeweils gleichen Abständen errechnet.

{phang2} {stata graph twoway scatter mpg price, colorvar(weight2) colordiscrete colorstart(red) colorend(green)} {p_end}

{pstd}
Da den vorgegebenen Farbbezeichnungen (z.B. {cmd:red}, {cmd:green}) konkrete Farbkodierungen zugrunde liegen (z.B. RGB- oder CMYK-Codes), ist es empfehlenswert, diese auch für die Farbdefinitionen zu verwenden.

{phang2} {stata graph twoway scatter mpg price, colorvar(weight2) colordiscrete colorstart(255 0 0) colorend(255 0 255)} {p_end}

{pstd}
Die {cmd:colorvar}-Option ist in Stata 18 (bisher) für Streu- und Balkendiagramme anwendbar. Mit StataNow steht sie auch für Liniendiagramme zur Verfügung.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{title:Ein einfaches Balkendiagramm}

{pstd}
Für ein zweites Beispiel laden wir jetzt einen anderen Stata-Beispieldatensatz, der Informationen über den täglichen Preis einer Aktie sowie über deren Preisveränderungen enthält.

{phang2} {stata sysuse "sp500.dta", clear} {p_end}

{pstd}
Wir erstellen hier ein Balkendiagramm, das uns die täglichen Veränderungen des Aktienpreises als positiven bzw. negativen Balken zeigt.

{phang2} {stata graph twoway bar change date} {p_end}

{pstd}
Als zusätzlich Drittvariable wollen wir in das Diagramm noch das tägliche Handelvolumen der Aktie einbringen. Dies können wir wieder mit der {cmd:}colorvar}-Option tun.

{phang2} {stata graph twoway bar change date, colorvar(volume)} {p_end}

{pstd}
Da die Drittvariable kontinuierlich ist, wird sie automatisch in farblich unterscheidbare Kategorien eingeteilt. Wir können diese Einteilung mit der {cmd:colorcuts}-Option beeiflussen. Als Parameter geben wir den Start- und den Endwert sowie dazwischen die Intervalle der Klassengrenzen an.

{phang2} {stata graph twoway bar change date, colorvar(volume) colorcuts(5000(10000)25000)} {p_end}

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{marker documents}
{hline}

{center:{ul on}{yellow:2) Dynamische Dokumentenerstellung mit Stata-Ergebnissen}{ul off}}

{pstd}
Alle, die die Ergebnisse ihrer statistischen Analyse mit Stata in Textform liefern müssen (z.B. als Berichte oder wissenschaftliche Artikel), kennen dieses lästige Problem:
Aus verschiedensten Gründen können sich im Laufe des Produktionsprozesses Analyseergebnisse verändern.

{pstd}
Dies kann durch Updates oder Korrekturen der Sekundärdaten passieren, die in unregelmäßigen Abständen von den Datenproduzierenden Organisationen vorgenommen werden.
Natürlich findet man in der eigenen Analyse selbst auch immer wieder Fehler oder trifft andere Entscheidungen in Bezug auf die Spezifikation eines statistischen Modells oder der Stichprobe.

{pstd}
Haben Sie sich nun für den klassischen und weitverbreiteten Weg entschieden, die von Stata ausgegebenen Tabellen und Grafiken per Hand in Ihren Text zu kopieren, müssen Sie dies u.U. häufig wiederholen.
Das ist eine der weniger angenehmen Tätigkeiten im Rahmen von Datenanalysen, unter der i.d.R. vor allem Hilfskräfte leiden.

{pstd}
Eine immer populärere Lösung sind sog. 'dynamische Dokumente', die neben dem fixierten geschriebenen Text auch Stata-Befehle als dynamischen Teil enthalten. 
Mit den Befehlen {cmd:dyntext} und {cmd:dyndoc} können Sie Ihre Text-Dokumente dynamisieren, und ich werde Ihnen hier kurz das Prinzip erläutern.

{hline}

{title:Ein einfaches Beispiel}

{pstd}
Wenn Sie mit einem Standard-Text-Editor das Dokument {cmd:exdyntext.txt} öffnen, sehen Sie neben dem Fließtext auch Stata-Befehle, die in sog. 'tags'}' eingebunden sind ("{cmd:<<[tag]>>}").
Diese Datei können Sie dann mit dem Befehl {cmd:dyntext} aufrufen und in eine neue Text-Datei umwandeln. 
Dabei werden die Stata-Befehle erneut ausgeführt.

{phang2} {stata dyntext "exdyntext.txt", saving("results.txt") replace} {p_end}

{pstd}
Die Datei {cmd:exdyntext.txt} mit den dynamischen Stata tags wird nun in eine andere Datei {cmd:results.txt} transformiert, die die aktualisierten Ergebnisse der Stata-Befehle enthält.

{pstd}
Mit {cmd:dyntext} werden die Ausgaben der Befehle aus Statas Results-Fenster in die Text-Datei geschrieben.
Für Tabellen ist das ausreichend, aber leider können txt-Dateien keine Bilder enthalten, so dass hier keine Grafiken eingebunden werden können.
Letzteres kann man allerdings mit dem {cmd:dyndoc}-Befehl erreichen (siehe unten).

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{hline}

{title:Statas dynamic tags}

{pstd}
Mit den sog. 'dynamic tags' stellt Stata die Möglichkeit zur Verfügung, in Text- oder Word-Dateien Anweisungen zur Ausführung von Stata-Befehlen zu platzieren.
Alle dynamic tags fangen mit "{cmd:<<}" an und werden mit "{cmd:>>}" beendet. 
In der Beispiel-Datei {cmd:exdyntext.txt} haben Sie die beiden wichtigsten tags bereits kennen gelernt:

{phang2} {cmd:<<dd_do>>} {p_end}

{pstd}
sowie

{phang2} {cmd:<</dd_do>>} {p_end}

{pstd}
Diese beiden tags umrahmen einen oder mehrere Stata-Befehle, die beim Umwandeln mit {cmd:dyntext} oder {cmd:dyndoc} ausgeführt werden.
Sie können hier eine komplexe Analyse mit vielen Befehlen durchführen.
Alle im Ergebnis-Fenster von Stata ausgegebenen Tabellen und Statistiken werden dann automatisch in die Ausgabe-Datei geschrieben.

{pstd}
Wollen Sie im Ergebnis-Dokument nur den Output aus dem Ergebnis-Fenster, nicht aber den Befehl selbst ausgegeben haben, ergänzen Sie den tag um das Attribut {cmd:nocommands}:

{phang2} {cmd:<<dd_do: nocommands>>} {p_end}
{phang3} ...{p_end}
{phang2} {cmd:<</dd_do>>} {p_end}

{pstd}
In der Beispiel-Datei wird vom {cmd:summarize}-Befehl, von den beiden {cmd:correlate}-Befehlen und vom {cmd:estimates table}-Befehl nur der Output angezeigt.

{pstd}
Ein weiteres Attribut zum tag {cmd:<<dd_do>>} ist {cmd:quietly}, das die gleiche Funktion hat, wie der gleichnamige Präfix bei Stata-Befehlen: die folgenden Befehle werden im Hintergrund ohne Ausgabe ausgeführt.

{pstd}
In der Beispiel-Datei {cmd:exdyntext.txt} wurde dieses Attribut für die {cmd:regress}- und {cmd:estimates store}-Befehle angewandt.
In einem Bericht oder wissenschaftlichen Text benötigt man die einzelnen Regressionstabellen i.d.R. nicht, sondern beschränkt sich auf eine Übersichtstabelle mit den Koeffizienten.

{pstd}
Weitere tags und deren Funktion finden Sie in Statas Hilfe-Funktion

{phang2} {stata help dynamic tags} {p_end}


{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{hline}

{title:Dynamische Word-Dokumente}

{pstd}
Bisher haben wir einen dynamischen Text mit Stata-Ergebnissen im ASCII-Format erzeugt. Meistens werden Texte allerdings mit Word geschrieben, das hinsichtlich der Formatierung alle Möglichkeiten einer Textverarbeitung bietet.
Vor allem können hier im Unterschied zu ASCII-Text-Dateien auch Grafiken direkt eingebaut werden. (In ASCII-Dateien geht das nur über den Umweg eines Links zu einer Grafik-Datei.)

{pstd}
Stata stellt dafür den Befehl {cmd:dyndoc} zur Verfügung, der in den Grundzügen genauso funktioniert wie {cmd:dyntext}. 
Allerdings steigt mit den Möglichkeiten auch die Komplexität, so dass die Demonstration eine Erstellung eines Word-Dokumentes unseren heutigen Zeitrahmen sprengen würde.
Deshalb verweise ich Sie hier auf Statas entsprechende Hilfe-Funktion:

{phang2} {stata help dyndoc} {p_end}

{pstd}
Auf der kommenden Stata-Konferenz 2025 wird es einen entsprechenden Workshop zu diesem Thema geben.

{hline}

{title:Word-Dokumente mit {cmd:putdocx}}

{pstd}
Eine weitere Möglichkeit, Word-Dokumente aus Stata zu erzeugen, bietet der Befehl {cmd:putdocx}. Mit Stata 18 wurde der Befehl um einige Facetten erweitert.
Es ist jetzt möglich, in Word-Dokumenten Grafiken und entsprechende Links einzubauen. Wenn Sie das Do-File {cmd:exputdocx.do} öffnen, finden Sie dort ein entsprechendes Beispiel.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{marker mediation}
{hline}

{center:{ul on}{yellow:3) Causal Mediation Analysis}{ul off}}

{hline}

{pstd}
Mit Stata 18 ist jetzt auch die detaillierte Analyse von Mediationseffekten möglich. Dabei lässt sich ein kausaler Effekt in direkte und indirekte Effekte aufteilen.
Mit dem neuen Befehl {cmd:mediate} lassen sich die Dekomposition und weitere Analysen sehr einfach durchführen. 

{pstd}
Beispielsweise wirkt der kausale Effekt eines hohen Schulabschlusses (Abitur) auf die Lebenszufriedenheit einerseits direkt und andererseits indirekt, beispielsweise über ein höheres Einkommen.
Es ist prinzipiell interessant und wichtig herauszufinden, in welchem Verhältnis direkte und indirekte Effekte stehen, da sich so kausale Mechanismen aufklären lassen.

{hline}

{title:Ein einfaches Beispiel}

{pstd}
Wir haben einen kleinen Beispieldatensatz konstruiert, der lediglich drei Variablen enthält.

{phang2} {stata use "data2.dta", clear} {p_end}
{phang2} {stata describe} {p_end}
{phang2} {stata summarize} {p_end}

{pstd}
Grundsätzlich interessieren wir uns für den Effekt des Abiturs ({cmd:abitur}) auf die Lebenszufriedenheit ({cmd:lsat}). Neben diesem direkten Effekt sind aber auch eine Reihe indirekter Effekte denkbar.
Einer davon könnte über das Erwerbseinkommen ({cmd:income}) vermittelt ("mediiert") werden: Der Schulabschluss Abitur führt zu einem höheren Einkommen, und dies wiederum zu einer höheren Lebenszufriedenheit.
Wir wollen also eine Dekomposition des {ul:totalen} Effektes des Abiturs auf die Lebenszufriedenheit in einen {ul:direkten} und einen {ul:indirekten} Effekt vornehmen.
In der Vergangenheit mussten wir dazu umständlich mehrere Regressionsmodelle schätzen; seit Stata 18 gibt es dazu einen einfachen und umfangreichen Befehl:

{phang2} {stata mediate (lsat) (income) (abitur), nointeraction} {p_end}

{pstd}
Die Spezifikation des Befehls erfordert - wie bei allen Stata-Regressionsbefehlen - zunächst die abhängige (Outcome-) Variable, gefolgt von der Mediator-Variable und schließlich der unabhängige (Treatment-) Variable.

{pstd}
Der Output zeigt für den "net indirect effect" (NIE) einen Koeffizienten von 0.064 und für den "net direct effect" (NDE) eine Effektstärke von 0.315.
Die Summe beider Koeffizienten ergibt den "total effect" (TE) von 0.379, der synonym zum ATE zu interpretieren ist.
Der größere Anteil des totalen Effektes wird also durch den direkten Effekt von Abitur auf Lebenszufriedenheit gebildet. Mit einem postestimation-Befehl können wir uns diese Anteile ausgeben lassen:

{phang2} {stata estat proportion} {p_end}

{pstd}
Hier wird der Anteil des indirekten Effektes am totalen Effekt angezeigt, der ca. 16.8% beträgt. Dementsprechend ist der direkte Effekt für 100% - 16.8% = 83.2% des totalen Effektes verantwortlich.


{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}

{hline}

{title:Ein erweitertes Beispiel}

{pstd}
Um in diesem Modell für potentielle Confounder zu kontrollieren, können wir zusätzliche Kovariaten einfügen.
Beispielsweise könnte das Geschlecht potentiell einen Einfluss auf alle drei Variablen haben.

{phang2} {stata pwcorr gender abitur income lsat, star(0.05)} {p_end}

{pstd}
zeigt uns, dass wir zumindest den indirekten Teileffekt von Abitur auf Einkommen mir Geschlecht kontrollieren müssen.

{phang2} {stata mediate (lsat gender) (income gender) (abitur), nointeraction} {p_end}

{pstd}
Das Ergebnis weicht nur minimal vom vorherigen ab.
Ein weiterer möglicher Confounder wäre das Alter, das vermutlich Einfluss auf Einkommen und Lebenszufriedenheit haben könnte und in diesem Fall diesen Teileffekt verzerren würde.

{phang2} {stata pwcorr age abitur income lsat, star(0.05)} {p_end}

{pstd}
Wir finden hier jeweils eine signifikante Korrelation zwischen Alter sowie Einkommen und Lebenszufriedenheit.
Auch dies können wir in das Modell einbauen:

{phang2} {stata mediate (lsat gender age) (income gender) (abitur), nointeraction} {p_end}
{phang2} {stata estat proportion} {p_end}

{pstd}
Die Koeffizienten verändern sich zwar leicht, aber die grundlegenden Effektverhältnisse sowie der Anteil des indirekten Effektes verbleiben in der gleichen Größenordnung.

{pstd}
Mit dem postestimation-Befehl {cmd:estat effectsplot} können wir alle drei Effekte (direkt, indirekt und total) grafisch darstellen:

{phang2} {stata estat effectsplot} {p_end}

{pstd}
Der {cmd:mediate}-Befehl erlaubt auch die Spezifizierung von nicht-linearen Effekten mit Hilfe von Logit oder Poisson-Modellen.

{right:{help webcast01##inhalt:[zurück zur Übersicht]}}{break}
